@@ -61,17 +61,29 @@ func newNode(name string, currentConfig, desiredConfig string) *corev1.Node {
 			state = daemonconsts.MachineConfigDaemonStateDone
 		} else {
 			state = daemonconsts.MachineConfigDaemonStateWorking
-		}		
+		}
 		annos = map[string]string{}
 		annos[daemonconsts.CurrentMachineConfigAnnotationKey] = currentConfig
 		annos[daemonconsts.DesiredMachineConfigAnnotationKey] = desiredConfig
 		annos[daemonconsts.MachineConfigDaemonStateAnnotationKey] = state
 	}
+	return newNodeWithAnnotations(name, annos)
+}
 
+func newNodeWithLabels(name string, labels map[string]string) *corev1.Node {
+	return &corev1.Node{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:   name,
+			Labels: labels,
+		},
+	}
+}
+
+func newNodeWithAnnotations(name string, annotations map[string]string) *corev1.Node {
 	return &corev1.Node{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:        name,
-			Annotations: annos,
+			Annotations: annotations,
 		},
 	}
 }
@@ -89,7 +101,7 @@ func newNodeWithLabel(name string, currentConfig, desiredConfig string, labels m
 
 func newNodeWithReady(name string, currentConfig, desiredConfig string, status corev1.ConditionStatus) *corev1.Node {
 	node := newNode(name, currentConfig, desiredConfig)
-	node.Status = corev1.NodeStatus{Conditions: []corev1.NodeCondition{{Type: corev1.NodeReady, Status: status}}}	
+	node.Status = corev1.NodeStatus{Conditions: []corev1.NodeCondition{{Type: corev1.NodeReady, Status: status}}}
 	if node.Annotations == nil {
 		node.Annotations = map[string]string{}
 	}
@@ -98,7 +110,7 @@ func newNodeWithReady(name string, currentConfig, desiredConfig string, status c
 
 func newNodeWithReadyAndDaemonState(name string, currentConfig, desiredConfig string, status corev1.ConditionStatus, dstate string) *corev1.Node {
 	node := newNode(name, currentConfig, desiredConfig)
-	node.Status = corev1.NodeStatus{Conditions: []corev1.NodeCondition{{Type: corev1.NodeReady, Status: status}}}	
+	node.Status = corev1.NodeStatus{Conditions: []corev1.NodeCondition{{Type: corev1.NodeReady, Status: status}}}
 	if node.Annotations == nil {
 		node.Annotations = map[string]string{}
 	}
@@ -249,7 +261,7 @@ func TestGetUnavailableMachines(t *testing.T) {
 			newNodeWithReady("node-2", "v0", "v2", corev1.ConditionTrue),
 		},
 		currentConfig: "v2",
-		unavail: []string{"node-0", "node-2"},
+		unavail:       []string{"node-0", "node-2"},
 	}, {
 		// 1 node updated, 1 updating, 1 updating but not v2 and is not ready
 		nodes: []*corev1.Node{
@@ -598,7 +610,7 @@ func TestCalculateStatus(t *testing.T) {
 	for idx, test := range tests {
 		t.Run(fmt.Sprintf("case#%d", idx), func(t *testing.T) {
 			pool := &mcfgv1.MachineConfigPool{
-				Status: mcfgv1.MachineConfigPoolStatus{
+				Spec: mcfgv1.MachineConfigPoolSpec{
 					Configuration: mcfgv1.MachineConfigPoolStatusConfiguration{ObjectReference: corev1.ObjectReference{Name: test.currentConfig}},
 				},
 			}
